@@ -6,7 +6,7 @@ use Mojolicious::Plugin::AssetPack::Asset::Null;
 use Mojolicious::Plugin::AssetPack::Store;
 use Mojolicious::Plugin::AssetPack::Util qw(diag has_ro load_module DEBUG);
 
-our $VERSION = '2.06';
+our $VERSION = '2.08';
 
 has minify => sub { shift->_app->mode eq 'development' ? 0 : 1 };
 
@@ -218,7 +218,7 @@ sub _serve {
 
 sub _static_asset {
   my ($self, $topic) = @_;
-  my $asset = $self->store->asset($topic) or die qq(No assets registered by topic "$topic".);
+  my $asset  = $self->store->asset($topic) or die qq(No assets registered by topic "$topic".);
   my $assets = Mojo::Collection->new($asset);
   $self->{by_checksum}{$_->checksum} = $_ for @$assets;
   return $assets;
@@ -234,7 +234,7 @@ Mojolicious::Plugin::AssetPack - Compress and convert css, less, sass, javascrip
 
 =head1 VERSION
 
-2.06
+2.08
 
 =head1 SYNOPSIS
 
@@ -274,6 +274,14 @@ for processing static assets. The idea is that JavaScript and CSS files should
 be served as one minified file to save bandwidth and roundtrip time to the
 server.
 
+Note that the main author have moved on to using
+L<Mojolicious::Plugin::Webpack> instead, which uses
+L<https://webpack.js.org/> under the hood, but is just as convenient to use as
+this plugin. It is very easy to try out
+L<Mojolicious::Plugin::Webpack>, since it will detect your AssetPack
+based project automatically, and migrate them over to webpack once the plugin
+is loaded.
+
 There are many external tools for doing this, but integrating them with
 L<Mojolicious> can be a struggle: You want to serve the source files directly
 while developing, but a minified version in production. This assetpack plugin
@@ -442,6 +450,8 @@ See L<Mojo::UserAgent::Proxy/detect> for more information.
 
 =head1 SEE ALSO
 
+L<Mojolicious::Plugin::Webpack>.
+
 L</GUIDES>,
 L<Mojolicious::Plugin::AssetPack::Asset>,
 L<Mojolicious::Plugin::AssetPack::Pipe> and
